<!--
name: 'System Reminder: Invoked skills'
description: List of skills invoked in this session
ccVersion: 2.1.18
variables:
  - FORMATTED_SKILLS_LIST
-->
The following skills were invoked in this session. Continue to follow these guidelines:

${FORMATTED_SKILLS_LIST}
